@@ -1,6 +1,8 @@
 import copy
 import os
 import typing as t
+import packaging
+from packaging.version import parse
 
 from dimensigon.domain.entities import Server
 from dimensigon.domain.entities.base import DistributedEntityMixin, UUIDistributedEntityMixin, SoftDeleteMixin
@@ -19,8 +21,8 @@ class SoftwareServerAssociation(DistributedEntityMixin, SoftDeleteMixin, db.Mode
     software = db.relationship("Software", back_populates="ssas", uselist=False)
     server = db.relationship("Server", backref="software_list", uselist=False)
 
-    def to_json(self):
-        data = super().to_json()
+    def to_json(self, **kwargs):
+        data = super().to_json(**kwargs)
         data.update({'software_id': str(self.software.id), 'server_id': str(self.server.id), 'path': self.path})
         return data
 
@@ -86,6 +88,10 @@ class Software(UUIDistributedEntityMixin, SoftDeleteMixin, db.Model):
             data.update(servers=servers)
         return data
 
+    @property
+    def parsed_version(self):
+        return parse(self.version) if self.version else None
+
     @classmethod
     def from_json(cls, kwargs):
         kwargs = copy.deepcopy(kwargs)
